pitchtools.PitchObject
======================

.. abjad-lineage:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject

.. autoclass:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__repr__
   :noindex:
